@@ -158,6 +158,19 @@ class GitBranch(object):
                 res.append(self.__get_branch(git_path))
         return res
 
+    def get_depth(self, branch):
+        """ Gets the depth of the repository
+
+            :param branch: Config dictionary of the repository
+            :return: Depth or False
+        """
+        depth = branch.get('depth', False)
+        if not depth:
+            return depth
+        if depth == 0:
+            return False
+        return depth
+
     def __clone(self, path, branch):
         """ Clones a repository in the specified path
 
@@ -165,7 +178,7 @@ class GitBranch(object):
             :param branch: Config dictionary of the repository
             :return: Message dictionary
         """
-        depth = branch.get('depth', False)
+        depth = self.get_depth(branch)
         clone_path = os.path.join(path, branch['path'])
         url = branch['repo_url'].get('origin', list(branch['repo_url'].values())[0])
         _logger.debug('Cloning repo %s - branch %s', branch['name'], branch['branch'])
@@ -201,13 +214,13 @@ class GitBranch(object):
             else:
                 res = self.__pull(branch, clone_path)
             if res['exit_code'] != 0:
-                branch.update({'depth': False})
+                branch.update({'depth': 0})
                 utils.clean_files(clone_path)
                 res = self.__clone(path, branch)
                 if branch.get('commit', False):
                     res = self.reset(branch, path)
         elif branch.get('commit', False):
-            branch.update({'depth': False})
+            branch.update({'depth': 0})
             res = self.__clone(path, branch)
             if res['exit_code']:
                 return res
